@@ -130,11 +130,6 @@ class VulkanConventions(ConventionsBase):
         else:
             return None
 
-    @property
-    def xml_supported_name_of_api(self):
-        """Return the supported= attribute used in API XML"""
-        return 'vulkan'
-
     @property
     def api_prefix(self):
         """Return API token prefix"""
@@ -195,7 +190,7 @@ class VulkanConventions(ConventionsBase):
     @property
     def extra_refpage_headers(self):
         """Return any extra text to add to refpage headers."""
-        return 'include::../config/attribs.txt[]'
+        return 'include::{config}/attribs.txt[]'
 
     @property
     def extension_index_prefixes(self):
@@ -259,3 +254,12 @@ class VulkanConventions(ConventionsBase):
         """Return path relative to the generated reference pages, to the
            generated API include files."""
         return "{generated}"
+
+    def valid_flag_bit(self, bitpos):
+        """Return True if bitpos is an allowed numeric bit position for
+           an API flag bit.
+
+           Vulkan uses 32 bit Vk*Flags types, and assumes C compilers may
+           cause Vk*FlagBits values with bit 31 set to result in a 64 bit
+           enumerated type, so disallows such flags."""
+        return bitpos >= 0 and bitpos < 31
